@@ -32,5 +32,5 @@ func (h *handler) importFeeds(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	json.Created(w, r, map[string]string{"message": "Feeds imported successfully"})
+	json.Created(w, r, importFeedsResponse{Message: "Feeds imported successfully"})
 }
