@@ -18,9 +18,11 @@ type FeedForm struct {
 	Description                 string
 	ScraperRules                string
 	RewriteRules                string
+	UrlRewriteRules             string
 	BlocklistRules              string
 	KeeplistRules               string
-	UrlRewriteRules             string
+	BlockFilterEntryRules       string
+	KeepFilterEntryRules        string
 	Crawler                     bool
 	UserAgent                   string
 	Cookie                      string
@@ -42,6 +44,7 @@ type FeedForm struct {
 	NtfyTopic                   string
 	PushoverEnabled             bool
 	PushoverPriority            int
+	ProxyURL                    string
 }
 
 // Merge updates the fields of the given feed.
@@ -53,9 +56,11 @@ func (f FeedForm) Merge(feed *model.Feed) *model.Feed {
 	feed.Description = f.Description
 	feed.ScraperRules = f.ScraperRules
 	feed.RewriteRules = f.RewriteRules
+	feed.UrlRewriteRules = f.UrlRewriteRules
 	feed.BlocklistRules = f.BlocklistRules
 	feed.KeeplistRules = f.KeeplistRules
-	feed.UrlRewriteRules = f.UrlRewriteRules
+	feed.BlockFilterEntryRules = f.BlockFilterEntryRules
+	feed.KeepFilterEntryRules = f.KeepFilterEntryRules
 	feed.Crawler = f.Crawler
 	feed.UserAgent = f.UserAgent
 	feed.Cookie = f.Cookie
@@ -77,6 +82,7 @@ func (f FeedForm) Merge(feed *model.Feed) *model.Feed {
 	feed.NtfyTopic = f.NtfyTopic
 	feed.PushoverEnabled = f.PushoverEnabled
 	feed.PushoverPriority = f.PushoverPriority
+	feed.ProxyURL = f.ProxyURL
 	return feed
 }
 
@@ -86,6 +92,7 @@ func NewFeedForm(r *http.Request) *FeedForm {
 	if err != nil {
 		categoryID = 0
 	}
+
 	ntfyPriority, err := strconv.Atoi(r.FormValue("ntfy_priority"))
 	if err != nil {
 		ntfyPriority = 0
@@ -105,9 +112,11 @@ func NewFeedForm(r *http.Request) *FeedForm {
 		UserAgent:                   r.FormValue("user_agent"),
 		Cookie:                      r.FormValue("cookie"),
 		RewriteRules:                r.FormValue("rewrite_rules"),
+		UrlRewriteRules:             r.FormValue("urlrewrite_rules"),
 		BlocklistRules:              r.FormValue("blocklist_rules"),
 		KeeplistRules:               r.FormValue("keeplist_rules"),
-		UrlRewriteRules:             r.FormValue("urlrewrite_rules"),
+		BlockFilterEntryRules:       r.FormValue("block_filter_entry_rules"),
+		KeepFilterEntryRules:        r.FormValue("keep_filter_entry_rules"),
 		Crawler:                     r.FormValue("crawler") == "1",
 		CategoryID:                  int64(categoryID),
 		Username:                    r.FormValue("feed_username"),
@@ -126,5 +135,6 @@ func NewFeedForm(r *http.Request) *FeedForm {
 		NtfyTopic:                   r.FormValue("ntfy_topic"),
 		PushoverEnabled:             r.FormValue("pushover_enabled") == "1",
 		PushoverPriority:            pushoverPriority,
+		ProxyURL:                    r.FormValue("proxy_url"),
 	}
 }
